from fake_useragent import UserAgent

class Agent:
    def __init__(self):
        self.useragent = UserAgent()

    def get(self):
        return self.useragent.random
    
    def get_bs4(self):
        return {
            "User-Agent": self.useragent.random
        }
    
    def change(self):
        self.useragent = UserAgent()
        




import requests
import random
import json
import os


class Proxies:
    def __init__(self):
        if not os.path.exists("proxies.json"):
            response = requests.get(
                "https://api.proxyscrape.com/v3/free-proxy-list/get?request=displayproxies&proxy_format=protocolipport&format=json")
            data = response.json()["proxies"]

            if not os.path.exists("Data"): os.mkdir("Data")

            with open("Data/proxies.json", 'w') as file:
                json.dump(data, file, indent=4)

        self.proxies = json.load(open("Data/proxies.json"))

    def get_bs4(self):
        proxy = random.choice(self.proxies)
        return {f"{proxy["protocol"]}": f"http://{proxy["proxy"]}", }

    def get(self):
        proxy = random.choice(self.proxies)
        return proxy["proxy"]


from setuptools import setup, find_packages

setup(
    name = "Thejairex",
    version= "0.1.2",
    description= "My personal package",
    author = "Thejaiex",
    author_email= "yairjesus777@gmail.com",
    packages= ["Thejairex"],
    install_requires = [
        'fake_useragent',
        'requests',
        ],
    classifiers= [
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License',

    ],
    python_requires= '>=3.6' 
)